@@ -1,11 +1,16 @@
 from abc import ABC
 from typing import Any, Callable, Iterable
-from front.elements import ElementTreeMakerBase
+from front.elements import (
+    COMPONENT_FLOAT,
+    COMPONENT_TEXT,
+    AppBase,
+    COMPONENT_INT,
+    CONTAINER_VIEW,
+    ElementTreeMakerBase,
+)
 from front.spec_maker import SpecMaker
-
 from front.types import FrontApp, FrontSpec, Map
-from front.elements import ContainerFlag, InputComponentFlag
-from front.elements.elements import AppBase
+from front.elements import AppBase, CONTAINER_VIEW
 from front.util import dflt_name_trans
 
 
@@ -22,26 +27,26 @@ def dflt_convention():
         'obj': {'trans': dflt_trans},
         'rendering': {
             Callable: {
-                'container': ContainerFlag.VIEW,
+                'container': CONTAINER_VIEW,
                 'inputs': {
-                    int: InputComponentFlag.INT,
+                    int: {'component': COMPONENT_INT,},
                     float: {
-                        'component': InputComponentFlag.FLOAT,
+                        'component': COMPONENT_FLOAT,
                         'format': '%.2f',
                         'step': 0.01,
                     },
-                    Any: InputComponentFlag.TEXT,
+                    Any: {'component': COMPONENT_TEXT,},
                 },
-                # 'output': {
-                #     int: OutputComponentFlag.NUMBER,
-                #     Any: OutputComponentFlag.TEXT
-                # }
             },
         },
     }
 
 
 class AppMakerBase(ABC):
+    """
+    Base class which 
+    """
+
     def __init__(
         self,
         element_tree_maker_factory: Callable,
@@ -53,11 +58,19 @@ class AppMakerBase(ABC):
     def mk_app(
         self, objs: Iterable[Any], config: Map = None, convention: Map = None
     ) -> FrontApp:
+        element_tree, app_spec = self._element_tree_and_spec(objs, config, convention)
+        return self._mk_app(element_tree, app_spec)
+
+    # TODO: Find a way so this method does not do two things. Maybe consider the
+    # element tree to be part of the spec object.
+    def _element_tree_and_spec(
+        self, objs: Iterable[Any], config: Map = None, convention: Map = None
+    ):
         convention = convention or dflt_convention
         spec = self._mk_spec(config, convention)
         front_objs = self._prepare_objs(objs, spec.obj_spec)
-        app_el_tree = self._mk_element_tree(front_objs, spec.rendering_spec)
-        return self._mk_app(app_el_tree, spec.app_spec)
+        element_tree = self._mk_element_tree(front_objs, spec.rendering_spec)
+        return element_tree, spec.app_spec
 
     def _mk_spec(self, config: Map, convention: Map) -> FrontSpec:
         return self.spec_maker.mk_spec(config, convention)
