@@ -1,10 +1,8 @@
 from .elements import (
-    ContainerFlag,
-    InputComponentFlag,
     FrontElementBase,
     FrontContainerBase,
     FrontComponentBase,
-    ParamInputBase,
+    InputBase,
     TextInputBase,
     IntInputBase,
     FloatInputBase,
@@ -12,3 +10,5 @@ from .elements import (
     FuncViewBase,
 )
 from .tree_maker_base import ElementTreeMakerBase
+from .implementation import implement_component
+from .element_flags import *
